@@ -1,22 +1,10 @@
 /*
   This file is part of KDE Kontact.
 
-  Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
-  Copyright (c) 2002-2003 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
+  SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Use the kdepim version
@@ -55,7 +43,6 @@ public:
     KontactApp(int &argc, char **argv[])
         : KontactInterface::PimUniqueApplication(argc, argv)
         , mMainWindow(nullptr)
-        , mSessionRestored(false)
     {
         KLocalizedString::setApplicationDomain("kontact");
     }
@@ -79,7 +66,7 @@ public:
 
 private:
     QPointer<MainWindow> mMainWindow;
-    bool mSessionRestored;
+    bool mSessionRestored = false;
 };
 
 static void listPlugins()
@@ -219,7 +206,7 @@ int main(int argc, char **argv)
     if (!app.isSessionRestored()) {
         // There can only be one main window
         if (KMainWindow::canBeRestored(1)) {
-            MainWindow *mainWindow = new MainWindow();
+            auto *mainWindow = new MainWindow();
             app.setMainWindow(mainWindow);
             app.setSessionRestored(true);
             mainWindow->show();
